<?php

namespace Drupal\eca_parameters\Event;

use Drupal\Component\EventDispatcher\Event;
use Drupal\eca\Plugin\DataType\DataTransferObject;
use Drupal\parameters\Event\CollectionsPreparationEvent;

/**
 * Event for requesting a parameter.
 *
 * @internal
 *   This class is not meant to be used as a public API. It is subject for name
 *   change or may be removed completely, also on minor version updates.
 */
class RequestingParameterEvent extends Event {

  /**
   * The original collections preparation event.
   *
   * @var \Drupal\parameters\Event\CollectionsPreparationEvent
   */
  protected CollectionsPreparationEvent $event;

  /**
   * An instance holding event data accessible as Token.
   *
   * @var \Drupal\eca\Plugin\DataType\DataTransferObject|null
   */
  protected ?DataTransferObject $eventData = NULL;

  /**
   * Constructs a new RequestingParameterEvent object.
   *
   * @param \Drupal\parameters\Event\CollectionsPreparationEvent $event
   *   The original collections preparation event.
   */
  public function __construct(CollectionsPreparationEvent $event) {
    $this->event = $event;
  }

  /**
   * Get the original collections preparation event.
   *
   * @return \Drupal\parameters\Event\CollectionsPreparationEvent
   *   The preparation event.
   */
  public function getPreparationEvent(): CollectionsPreparationEvent {
    return $this->event;
  }

}
